SystemOrganization addCategory: #'GrandMa-Tests'!

TestCase subclass: #GMQueueTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GrandMa-Tests'!

!GMQueueTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/14/2012 15:07'!
testConsumeTask
	| q consumedTask |
	q := GMQueue new.
	q addTask:  (GMTask new command: 'first').
	q addTask: (GMTask new command: 'second').
	consumedTask := q consumeTask.
	self deny: consumedTask consumeDate isNil.
	self assert: q pendingTasks size equals: 1.! !

!GMQueueTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/11/2012 23:40'!
testFIFO
	| q |
	q := GMQueue new.
	q addTask: 'first'.
	q addTask: 'second'.
	self assert: q consumeTask equals: 'first'.
	self assert: q consumeTask equals: 'second'.
	self assert: q consumeTask isNil.! !

!GMQueueTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/13/2012 15:07'!
testSuccess
	| success q task |
	success := false.
	q := GMQueue new.
	task := GMTask new 
		command: 'first';
		callback: [ :output | success := true ].

	q addTask: task.
	q consumeTask.
	q success: (Dictionary new 
		at: #uuid put: task uuid;
		at: #message put: 'command output';
		yourself).
	self assert: q pendingTasks isEmpty.
	self assert: success.! !

TestCase subclass: #GMServerTest
	instanceVariableNames: 'testServer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GrandMa-Tests'!

!GMServerTest methodsFor: 'running' stamp: 'FrancoisStephany 4/14/2012 14:09'!
setUp
	testServer := GMServer startOn: 1777.! !

!GMServerTest methodsFor: 'running' stamp: 'FrancoisStephany 4/13/2012 16:52'!
tearDown
	testServer stop.! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/14/2012 15:12'!
testHandlePop
	| response retrievedTask |
	testServer queue addTask: (GMTask new
		command: 'ls -a').
	response := ZnEasy post: 'http://localhost:1777/pop' data: (ZnEntity text: '').
	self assert: response code equals: 200.
	retrievedTask := Json readFrom: response contents readStream.
	self assert: (retrievedTask at: 'command') equals: 'ls -a'.! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/14/2012 14:56'!
testHandlePush
	| data response |
	data := Dictionary new
		at: #uuid put: 'AZERTY';
		at: #command put: 'ls -a';
		yourself.
	response := ZnEasy post: 'http://localhost:1777/push' data: (ZnEntity text: data asJsonString).
	self assert: response code equals: 200.
	self deny: testServer queue tasks isEmpty.! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/14/2012 14:12'!
testHandleRequest
	| response |
	response := ZnEasy get: 'http://localhost:1777/push'.
	self assert: response code equals: 405.
	
	response := ZnEasy post: 'http://localhost:1777/blop' data: (ZnEntity text: 'blop').
	self assert: response code equals: 404.
! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/15/2012 11:55'!
testHandleSuccess
	| popResponse taskToPerform successDictionary successResponse |
	"add the task"
	testServer queue addTask: (GMTask new
		command: 'ls -a').
	"pop it"
	popResponse := ZnEasy post: 'http://localhost:1777/pop' data: (ZnEntity text: '').
	taskToPerform := Json readFrom: popResponse contents readStream.
	
	successDictionary := Dictionary new
		at: #uuid put: taskToPerform uuid;
		at: #success put: 'we did it!!';
		yourself.
	
	successResponse := ZnEasy 
		post: 'http://localhost:1777/success' data: (ZnEntity text: successDictionary asJsonString).
	self assert: successResponse isSuccess.
	self assert: testServer queue pendingTasks isEmpty.
	! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/13/2012 16:51'!
testSingleton
	self deny: GMServer current isNil.
	self assert: GMServer current zincServer isRunning.
	self assert: GMServer current zincServer port equals: 7070.! !

!GMServerTest methodsFor: 'tests' stamp: 'FrancoisStephany 4/13/2012 16:54'!
testStopStart
	self assert: testServer isRunning.
	testServer stop.
	self deny: testServer isRunning.
	testServer start.
	self assert: testServer isRunning.! !

TestCase subclass: #GMTaskTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GrandMa-Tests'!

!GMTaskTest methodsFor: 'test' stamp: 'FrancoisStephany 4/13/2012 15:12'!
testInitialize
	| a b |
	a := GMTask new.
	b := GMTask new.
	self deny: a uuid isNil.
	self deny: a uuid = b uuid.
	self deny: a callback isNil.! !
